<?php 
/*
 * dadibd-class.php
 * 
 * Class to build Dadi Breadcrumb in the Wordpress template
 * 
 * @version 	1.1.1 2016/12/29
 * @package 	Dadi Breadcrumb Plugin
 * @copyright	Copyright 2016 DAVIDE MURA  (email: muradavi@gmail.com)
 * @license		GNU General Public License GPLv2
 * @since Since Release 1.0
 * 
 **********************************************************************/


/*
 * Class to build breadcrumb
 *  
 * This class builds the breadcrumb for each type of content
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 * 
 */	
class DadiBd {
	
	/* 
	 * Class Properties 
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.0 2016/05/19 
	 */
	
	protected $_option; // array of values
	
	
	/*
	 * The __construct method
	 *  
	 * @param: 		$args (array)
	 * @return: 	mixed values (bool|string|int)
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.0 2016/05/19
	 */
	public function __construct( $args ) {
		
		if( !is_array( $args ) ) $args = array();
		
		$this->_option = $args;
	
	}
	

	/* 
	 * Build breadcrumb for single post
	 *  
	 * @param: 		none
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.1 2016/07/06
	 */
	protected function _get_breadcrumb_post() {
		
		// build breadcrumb
		$output  = '';		
		$output .= '<div id="breadcrumbs" itemprop="breadcrumb" class="dadibd-breadcrumb' . $this->_option['theme_class'] . '">';
		$output .= $this->_option['home_icon'];
		$output .= '<a rel="home" href="' . $this->_option['home_url'] . '"><span>Home</span></a>' . $this->_option['separator'];
		$output .= $this->_option['position_date'] == 0 ? $this->_option['date_post'] : '';
		
		// if has categories or terms
		if( $this->_option['is_display_terms'] ) {
			$output .= $this->_option['display_terms'];
		}
		
		$output .= $this->_option['position_date'] == 1 ? $this->_option['date_post'] : '';
		$output .= $this->_option['virtual_dir'] != '' ? '<span>' . $this->_option['virtual_dir'] . '</span>' . $this->_option['separator'] : '';
		$output .= '<strong>' . $this->_option['post_title'] . '</strong>';
		$output .= '</div>';
		
		
		// if we are into admin panel, in the metabox preview we display this alert if term selected is not checked
		if( $this->_option['is_admin']  ) {
			if( !$this->_option['check_isset_pt'] ) {
				$output .= '<hr /><span style="color:orange;font-size:.8em;">' . sprintf( __('Notice. You haven\'t checked option to display term/category for this post type. If you desire display term/category, go to %spage settings%s and check true for this custom post type.', 'dadibd' ),  '<a href="' . $this->_option['home_url'] . '/wp-admin/options-general.php?page=dadibd-options-page">', '</a>' ) . '</span>';
			} 
			else {
				
				if( !$this->_option['is_display_terms'] && $this->_option['term_name'] != '' ) {
					$term = $this->_option['term_name'] != '' ? 'the"' . $this->_option['term_name'] . '"' : __( 'any term/category', 'dadibd' );
					$output .= '<hr /><span style="color:red;font-size:.8em;">' . sprintf( __('This post isn\'t inserted in %s! You must check this term/category or select checked term/category! Otherwise breadcrumb for this post will be displayed without any term or category', 'dadibd' ), $term ) . '</span>';
				}
				else {
					$output .= '';
				}
			}
		} else {
			$output .= '';
		}
		
		return $output;
		
	}
	
	
	/*
	 * Build breadcrumb for singular post ( custom post type different to post )
	 *  
	 * @param: 		none
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.1 2016/07/06
	 */
	protected function _get_breadcrumb_custom_type() {
		
		// build breadcrumb
		$output = '';
		$output .= '<div id="breadcrumbs" itemprop="breadcrumb" class="dadibd-breadcrumb' . $this->_option['theme_class'] . '">';
		$output .= $this->_option['home_icon'];
		$output .= '<a rel="home" href="' . $this->_option['home_url'] . '"><span>Home</span></a>' . $this->_option['separator'];
		$output .= $this->_option['post_type_name'] . $this->_option['separator'];
		$output .= $this->_option['position_date'] == 0 ? $this->_option['date_post'] : '';
		
		// if has categories or terms
		if( $this->_option['is_display_terms'] ) {
			$output .= $this->_option['display_terms'];
		}
		
		$output .= $this->_option['position_date'] == 1 ? $this->_option['date_post'] : '';
		$output .= '<strong>' . $this->_option['post_title'] . '</strong>';
		$output .= '</div>';
		
		// if we are into admin panel, in the metabox preview we display this alert if term selected is not checked
		if( $this->_option['is_admin']  ) {
			if( !$this->_option['check_isset_pt'] ) {
				$output .= '<hr /><span style="color:orange;font-size:.8em;">' . sprintf( __('Notice. You haven\'t checked option to display term/category for this post type. If you desire display term/category, go to %spage settings%s and check true for this custom post type.', 'dadibd' ),  '<a href="' . $this->_option['home_url'] . '/wp-admin/options-general.php?page=dadibd-options-page">', '</a>' ) . '</span>';
			} 
			else {
				
				if( !$this->_option['is_display_terms'] && $this->_option['term_name'] != '' ) {
					$term = $this->_option['term_name'] != '' ? 'the"' . $this->_option['term_name'] . '"' : __( 'any term/category', 'dadibd' );
					$output .= '<hr /><span style="color:red;font-size:.8em;">' . sprintf( __('This post isn\'t inserted in %s! You must check this term/category or select checked term/category! Otherwise breadcrumb for this post will be displayed without any term or category', 'dadibd' ), $term ) . '</span>';
				}
				else {
					$output .= '';
				}
			}
		} else {
			$output .= '';
		}
		
		return $output;
		
	}
	
	
	/* 
	 * Build breadcrumb for static page
	 *  
	 * @param:		none
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.1 2016/07/06 
	 */
	protected function _get_breadcrumb_page() {
		
		// build breadcrumb
		$output  = '';
		$output .= '<div id="breadcrumbs" itemprop="breadcrumb" class="dadibd-breadcrumb' . $this->_option['theme_class'] . '">';
		$output .= $this->_option['home_icon'];
		$output .= '<a rel="home" href="' . $this->_option['home_url'] . '"><span>Home</span></a>' . $this->_option['separator'];
		$output .= '<strong>' . $this->_option['post_title'] . '</strong>';
		$output .= '</div>';
		
		return $output;
		
	}
	
	
	/*
	 * Build breadcrumb for archive page
	 *  
	 * @param: 		none
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.1 2016/07/06 
	 */
	protected function _get_breadcrumb_archives() {
		
		// build breadcrumb
		$output  = '';
		$output .= '<div id="breadcrumbs" itemprop="breadcrumb" class="dadibd-breadcrumb' . $this->_option['theme_class'] . '">';
		$output .= $this->_option['home_icon'];
		$output .= '<a rel="home" href="' . $this->_option['home_url'] . '"><span>Home</span></a>' . $this->_option['separator'];
		$output .= $this->_option['archive_data'];
		$output .= '</div>';
		
		return $output;
		
	}
	
	
	/* 
	 * Build breadcrumb for search page
	 *  
	 * @param: 		none
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.1 2016/07/06
	 */
	protected function _get_breadcrumb_search() {
		
		$output  = '';
		$output .= '<div id="breadcrumbs" itemprop="breadcrumb" class="dadibd-breadcrumb' . $this->_option['theme_class'] . '">';
		$output .= $this->_option['home_icon'];
		$output .= '<a rel="home" href="' .  $this->_option['home_url'] . '"><span>Home</span></a>' . $this->_option['separator'];
		$output .= '<span>' . __( 'Search Term', 'dadibd' ) . '</span>' . $this->_option['separator'];
		$output .= '<strong>' . $this->_option['search_query'] . '</strong>';
		$output .= '</div>';
		
		return $output;
		
	}
	
	
	/* 
	 * Build breadcrumb for author page
	 *  
	 * @param: 		none
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.1 2016/07/06
	 */
	protected function _get_breadcrumb_author() {
	
		// build breadcrumb
		$output  = '';
		$output .= '<div id="breadcrumbs" itemprop="breadcrumb" class="dadibd-breadcrumb' . $this->_option['theme_class'] . '">';
		$output .= $this->_option['home_icon'];
		$output .= '<a rel="home" href="' . $this->_option['home_url'] . '"><span>Home</span></a>' . $this->_option['separator'];
		$output .= '<span>' . __( 'Author', 'dadibd' ) . '</span>' . $this->_option['separator'];
		$output .= '<strong>' . $this->_option['author_name'] . '</strong>';
		$output .= '</div>';
		
		return $output;
		
	}
	
	
	/* 
	 * Build breadcrumb for attachment page
	 *  
	 * @param: 		none
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.1 2016/07/06 
	 */
	protected function _get_breadcrumb_attachment() {
		
		// build breadcrumb
		$output  = '';
		$output .= '<div id="breadcrumbs" itemprop="breadcrumb" class="dadibd-breadcrumb' . $this->_option['theme_class'] . '">';
		$output .= $this->_option['home_icon'];
		$output .= '<a rel="home" href="' . $this->_option['home_url'] . '"><span>Home</span></a>' . $this->_option['separator'];
		$output .= '<span>' . $this->_option['att_parent_title'] . '</span>';
		$output .= '<strong>' . $this->_option['att_title'] . '</strong>';
		$output .= '</div>';
		
		return $output;
		  
	}
	
	
	/* 
	 * Build breadcrumb for 404 error page
	 *  
	 * @param: 		none
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.1 2016/07/06
	 */
	protected function _get_breadcrumb_404() {
		
		// build breadcrumb
		$output = '';
		$output .= '<div id="breadcrumbs" itemprop="breadcrumb" class="dadibd-breadcrumb' . $this->_option['theme_class'] . '">';
		$output .= $this->_option['home_icon'];
		$output .= '<a rel="home" href="' . $this->_option['home_url'] . '">Home</a>' . $this->_option['separator'];
		$output .= '<strong>' . __( '404 Error Page', 'dadibd' ) . '</strong>';
		$output .= '</div>';
		
		return $output;
		  
	}
	
	/* 
	 * Create a public method for print breadcrumb out of the class
	 *  
	 * @param: 		$post -> current post
	 * @return: 	string
	 * 
	 * @package 	Dadi Breadcrumb
	 * @since 		Since Release 1.0
	 * @version 	1.0 2016/05/19 
	 */
	public function getDadiBreadcrumb( $label ) {
		
		$breadcrumb = '';
		
		switch( $label ) {
			
			case 'post' :
			$breadcrumb = $this->_get_breadcrumb_post();
			break;
			case 'page' :
			$breadcrumb = $this->_get_breadcrumb_page();
			break;
			case 'attachment' :
			$breadcrumb = $this->_get_breadcrumb_attachment();
			break;
			case 'custom_type' :
			$breadcrumb = $this->_get_breadcrumb_custom_type();
			break;
			case 'archive' :
			$breadcrumb = $this->_get_breadcrumb_archives();
			break;
			case 'author' :
			$breadcrumb = $this->_get_breadcrumb_author();
			break;
			case 'search' :
			$breadcrumb = $this->_get_breadcrumb_search();
			break;
			case '404' :
			$breadcrumb = $this->_get_breadcrumb_404();
			break;			
			
		}
		
		return $breadcrumb;
		
	}

}
