<?php
/*
 * dadibd-metabox.php
 * 
 * Add metabox for edit breadcrumb in a post and pages
 * 
 * @version 	1.1.1 2016/12/29
 * @package 	Dadi Breadcrumb Plugin
 * @copyright	Copyright 2016 DAVIDE MURA  (email: muradavi@gmail.com)
 * @license		GNU General Public License GPLv2
 * @since Since Release 1.0
 * 
 **********************************************************************/


/*
 * 
 * Add metabox to post and page
 *  
 * For reference (@param and @return) see: 
 * https://developer.wordpress.org/reference/functions/add_meta_box/
 * https://developer.wordpress.org/reference/functions/add_action/
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 * 
 */
function get_custom_breadcrumb(){ 
		
	$post_types = get_dadibd_list_post_type();
	
	add_meta_box("dadibreadcrumb", __('Dadi Breadcrumb', 'dadibd' ), "get_dadibd", $post_types, "normal" );
}
add_action('admin_init', 'get_custom_breadcrumb'); 


/*
 * 
 * Get the form for data
 *  
 * This is a callback function for get_custom_breadcrumb()
 * @param: none
 * @return: mixed value (bool|string)
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 * 
 */
function get_dadibd() {
	
	global $post;
	
	$custom = get_post_custom($post->ID);
	
	if ( ! isset( $custom["_get_custom_breadcrumb"] ) )
	$custom["_get_custom_breadcrumb"] = null;
	$postmeta = $custom["_get_custom_breadcrumb"][0]; 
	
	if ( ! isset( $custom["_get_custom_posttitle"] ) )
	$custom["_get_custom_posttitle"] = null;
	$postmeta_pt = $custom["_get_custom_posttitle"][0];	
	
	// get list of taxonomies by post_type
	$custom_taxonomies = get_object_taxonomies( $post->post_type );
	
	?>
	<table class="dadibd-breadcrumb-meta">
		<tr>
			<td>
				<div class="dadibd-title-preview"><?php _e( 'Preview: ', 'dadibd' ); ?></div>
				<div class="dadibd-breadcrumb-preview">
					<?php echo get_dadi_breadcrumb(); ?>
				</div>
				<hr />
				<?php if( $post->post_type != 'page' && $post->post_type != 'attachment' ) : ?>
				<p class="dadibd-dropdown">
				<?php 
					// if post_type_categories is isset or taxonomies exists for this post_type
					if( !empty( $custom_taxonomies ) ) : ?>
						
						<label for="dadibd-dropdown"><?php _e( 'Define navigation term/category', 'dadibd' ); ?></label><br /><?php
						
						// get list of public registered post types and builtin post types
						$posts_type = get_dadibd_list_post_type();
						
							// check if post_type exists in the array
							if( in_array( $post->post_type, $posts_type ) ) {
							
								// custom taxonomy get by dadi breadcrumb settings
								$taxonomy = get_dadibd_options( $post->post_type . '_get_taxonomies' ); 
								
								// if terms not exists or any term is set
								if( !has_term( '', $taxonomy, $post->ID ) ) {
									
									printf( __( '%sOps! Is unchecked any terms/categories for this post or terms/categories not exist!%s', 'dadibd' ), '<em>', '</em>' );
								
								} else {
								
									// we have now our dropdown
									wp_dropdown_categories( array(
										'id'					=> 'dadibd-dropdown',
										'show_option_none' 		=> __( 'No Term/Category', 'dadibd' ),
										'option_none_value'  	=> '-1',
										'hierarchical' 			=> 1,
										'hide_empty' 			=> 0,
										'name' 					=> '_get_custom_breadcrumb',
										'selected' 				=> $postmeta,
										'taxonomy'				=> $taxonomy
									) ); 
									
								}
								
							};
						
					else : ?>
						<span class="dadibd-notice">
							<?php _e( 'Notice. Taxonomy for this post type not exists or is empty, or isn\'t activated display terms/category in settings page', 'dadibd' ); ?>
						</span><?php 
					endif; ?>
					</p>
				<?php endif; ?>
				<p class="dadibd-post-title">
					<label for="dadibd-get-custom-posttitle"><?php _e( 'Insert a custom title', 'dadibd' ); ?></label><br />
					<input type="text" id="dadibd-get-custom-posttitle" name="_get_custom_posttitle" value="<?php echo $postmeta_pt != '' ? sanitize_text_field( $postmeta_pt ) : sanitize_text_field( $post->post_title ); ?>" />
				</p>
				<p class="dadibd-go-to-settings">
					<?php 
						printf( __( 'For other options and customizations, go to plugin %ssettings page%s.', 'dadibd' ), '<a href="' . esc_url( get_home_url() ) . '/wp-admin/options-general.php?page=dadibd-options-page">', '</a>' );
					?>
				</p>
			</td>
		</tr>
	</table>
	
	<?php wp_nonce_field( 'cb_action_nonce', 'cb_nonce' );
	
}


/*
 * 
 * Save metabox data
 *  
 * @param: none
 * @return: mixed values (bool|string)
 * 
 * For add_action reference (@param and @return) see: 
 * https://developer.wordpress.org/reference/functions/add_action/
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 * 
 */	
function save_data_dadibd(){ 
	
		global $post, $post_id;
		
		if( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) return $post_id;
		if( !isset( $_POST['cb_nonce'] ) || !wp_verify_nonce( $_POST['cb_nonce'], 'cb_action_nonce' ) ) return $post_id;
		
		if( isset( $_POST['_get_custom_breadcrumb'] ) ) {
			update_post_meta($post_id, "_get_custom_breadcrumb", esc_attr( $_POST["_get_custom_breadcrumb"] ) );

		}
		else {
			if( isset($post) ) {
				delete_post_meta( $post_id, "_get_custom_breadcrumb" );
			}
		}
		
		if( isset( $_POST['_get_custom_posttitle'] ) ) {
			update_post_meta($post_id, "_get_custom_posttitle", esc_attr( $_POST["_get_custom_posttitle"] ) );

		}
		else {
			if( isset($post) ) {
				delete_post_meta( $post_id, "_get_custom_posttitle" );
			}
		}
		
}
add_action('save_post', 'save_data_dadibd');
