<?php
/*
 * dadibd-options.php
 * 
 * Options form for dadibd-breadcrumb
 * 
 * @version 	1.1.1 2016/12/29
 * @package 	Dadi Breadcrumb Plugin
 * @copyright	Copyright 2016 DAVIDE MURA  (email: muradavi@gmail.com)
 * @license		GNU General Public License GPLv2
 * @since Since Release 1.0
 * 
 **********************************************************************/


/*
 * Get the form data
 * 
 * This is a callback function for dadibd_add_option_page(). See above
 * @param: none
 * @return: mixed values (bool|string|int)
 * 
 * @package Dadi Breadcrumb
 * @since Since Release 1.0
 * @version 1.0 2016/05/19
 */
function dadibd_update_options_form() {
	
	global $default, $jquery_positions, $separators;
	
	// get some predefinited arrays
	$inputs_array 		= get_dadibd_global_array_inputs();
	
	// get arrays defined above as globals
	$radio_icons 		= $inputs_array['radio_icons'];
	$date_elements		= $inputs_array['date_elements'];
	$author_type_names	= $inputs_array['author_type_names'];
	
	// delete options
	if( isset( $_REQUEST['action'] ) && ( 'reset' == $_REQUEST['action'] ) ) 
		delete_option( 'dadibd_options' );
	
	// create options variable by get_option wp function
	$options = get_option( 'dadibd_options', $default ); 
	
	// disable jquery harmonium
	$display_none = !get_dadibd_options( 'all_visible' ) ? 'style="display:none;"' : ''; 
	
	?>
	
	<div id="dadibd-container" class="wrap">
			<div class="icon32" id="icon-options-general"><br /></div>
			<h2><?php _e('Dadi Breadcrumb', 'dadibd'); ?></h2>
			<p>
				<?php _e( 'Dadi Breadcrumb inserts a powerful breadcrumb in your theme. You can customize it like you want. For example, you can define the
				specific target term/category of your breadcrumb for each post (and post type), provided that this term/category is assigned to your post. But there are many others options.
				See below and thank you to use Dadi Breadcrumb!', 'dadibd' ); ?>
				<br />
				<?php _e( 'Note. Other settings are activated inside metabox in each post type editor.', 'dadibd' ); ?>
			</p>
			<h3><?php _e( 'Global settings', 'dadibd' ); ?></h3>
			<form id="dadibd-form" method="post" action="options.php">
				<?php settings_fields('dadibd_options_group'); ?>
				<?php do_settings_sections( 'dadibd_options_group' ); ?>
				<p>
					<input type="checkbox" id="all-visible" name="dadibd_options[all_visible]" value="1" <?php checked( $options['all_visible'], 1 ); ?> />
					<label for="all-visible"><?php _e( 'Display all options at a glance. Will be disabled harmonium script (Hide/Show options box on click).', 'dadibd' ); ?></label>
				</p>
				<h3 class="spoiler" id="dadibd-hideshow-1"><?php _e( 'Manage Insert Options', 'dadibd' ); ?></h3>
				<div id="dadibd-hidden-1" <?php echo $display_none; ?>>
					<table class="dadibd-options" width="100%">
						<tr>
							<td>
								<p class="main-description">
									<?php _e( 'In this section you can manage method of breadcrumb integration in your template.', 'dadibd' ); ?>
								</p>
								<p class="label">
									<input type="radio" class="choose-method" id="dadibd-manual-append" name="dadibd_options[auto_append_breadcrumb]" value="0" <?php checked( $options['auto_append_breadcrumb'], 0 ); ?>>
									<?php _e( 'If you want insert manually the breadcrumb, copy and paste this function in your template wherever you want: ', 'dadibd' ); ?>
									<pre>&lt;?php echo get_dadi_breadcrumb(); ?&gt;</pre>
								</p>
								<p>
									<input type="radio" class="choose-method" id="dadibd-auto-append-to-loop" name="dadibd_options[auto_append_breadcrumb]" value="1" <?php checked( $options['auto_append_breadcrumb'], 1 ); ?>>
									<label for="dadibd-auto-append-to-loop">
										<?php _e( 'Check it if you want trying to auto-append Dadi Breadcrumb in your template before the Loop*.', 'dadibd' ); ?>
									</label>
								</p>
								<p>
									<span class="small"><?php _e( '(*)Execept for 404 Error page. For this page you must use jQuery option or insert breadcrumb manually. For reference see below.', 'dadibd' ); ?></span>
								</p>
								<p>
									<input type="radio" class="choose-method" id="dadibd-auto-append-with-jquery" name="dadibd_options[auto_append_breadcrumb]" value="2" <?php checked( $options['auto_append_breadcrumb'], 2 ); ?>>
									<label for="dadibd-auto-append-with-jquery">
										<?php _e( 'Check it if you want trying to append Dadi Breadcrumb in your template with jQuery.', 'dadibd' ); ?>
									</label><br />
									
									<?php $target_element = filter_dadibd_illegal_chars( $options['target_element_to_append'] ); ?>
									
									<script type="text/javascript">
									jQuery( function() {
										jQuery( ".choose-method").change( function() {
											if( jQuery("#dadibd-auto-append-with-jquery").is( ':checked' ) ) { 
												jQuery( "#div-hidden").css( 'display', 'block' );
											} else {
												jQuery( "#div-hidden").css( 'display', 'none' );
											}							
										});
									});
									</script>
								
								</p>
								<div id="div-hidden" style="display: <?php echo $options['auto_append_breadcrumb'] == 2 ? 'block' : 'none'; ?>;">
									
									<label for="target-class-to-append"><?php _e('You must define a target class or id. Allowed chars: letters, numbers, space, underscore, minus, dot, hash and colon. Other chars will be removed*.', 'dadibd' ); ?></label><br />
									<input type="text" id="target-class-to-append" name="dadibd_options[target_element_to_append]" value="<?php echo sanitize_text_field( $target_element ); ?>" /><br />
									
									<?php	
										// verify if exists dot or hash
										$_1 = preg_match_all( "/[\.#]\w/i", $target_element );
										$_2 = preg_match_all( "/\b\w/i", $target_element );
										if( $_1 !== $_2 ) { ?>
											<span class="dadibd-notice" style="margin-top:10px;">
												<?php _e( 'Notice. You could have lost a dot or an hash in your class or id. In theory, this can be correct (example if you call a tag), but the method could create duplicate breadcrumbs!', 'dadibd' ); ?>
											</span>
										<?php 
										} ?>
									<span class="small"><?php _e( '(*)Target class or id allows to insert Dadi Breadcrumb in a specific position relate to the element (div, talbe or list, etc.) that has class or id. Note: class or id must exists in your template and it will be a unique to avoid duplicates! Remember dot at beginning of class and hash at beginning of id! You can use also colon char for pseudoclasses.', 'dadibd' ); ?></span><br />
									
									<label for="type-of-position"><?php _e( 'Define addition (or position) of breadcrumb relate to target class or id.', 'dadibd' ); ?></label><br />
									
									<select name="dadibd_options[type_of_position]">
									<?php foreach( $jquery_positions as $position ) : ?>
										<option value="<?php echo $position; ?>" <?php selected( $options['type_of_position'], $position ); ?>><?php echo $position; ?></option>
									<?php endforeach; ?>
									</select>
									
									<ul class="legend">
										<li><?php _e( 'PREPEND: insert breadcrumb to the beginning of element that has target class|id.', 'dadibd' ); ?></li>
										<li><?php _e( 'APPEND: insert breadcrumb to the end of element that has target class|id.', 'dadibd' ); ?></li>
										<li><?php _e( 'BEFORE: insert breadcrumb before of element that has target class|id.', 'dadibd' ); ?></li>
										<li><?php _e( 'AFTER: insert breadcrumb after of element that has target class|id.', 'dadibd' ); ?></li>
									</ul>
								</div>								
							</td>
						</tr>
					</table>
				</div>
				
				<h3 class="spoiler" id="dadibd-hideshow-2"><?php _e( 'Manage Home Link Options', 'dadibd' ); ?></h3>
				<div id="dadibd-hidden-2" <?php echo $display_none; ?>>
					<table class="dadibd-options" width="100%">
						<tr>
							<td>
								<p class="main-description">
									<?php _e( 'In this section you can define type of icon for home link.', 'dadibd' ); ?>
								</p>
								<p class="label">
									<?php _e( 'Insert and set icon for home link', 'dadibd' ); ?>
								</p>
								<p>
								<?php
								$name_radio_icon = '';
								foreach( $radio_icons as $index => $value ) {
							
									$checked = $options['radio_icon'] == $value['value'] ? 'checked' : '' ;
									$input = '<input type="radio" id="dadibd-breadcrumb-' . esc_attr( $value['value'] ) . '" name="dadibd_options[radio_icon]" value="' . sanitize_text_field( $value['value'] ) . '" ' . $checked . '  >';
									$label = '<label for="dadibd-breadcrumb-' . esc_attr( $value['value'] ) . '">' . esc_html( $value['label'] ) . '</label><br />';
									echo $input . $label;
									
								} 
								?>
								</p>
								<p>
									<label for="dadibd-home-icon">
										<?php _e( 'Insert an absolute uri for icon image or insert target classes for glyphicon script (example: fa fa-icon).', 'dadibd' ); ?><br />
										<?php _e( 'HTML disallowed. Allowed images: png|jpg|gif', 'dadibd' ); ?>
									</label><br />
									<input type="text" id="dadibd-home-icon" name="dadibd_options[home_icon]" value="<?php echo sanitize_text_field( $options['home_icon'] ); ?>" />
								</p>
								<p>
									<?php
									$get_radio_icon = get_dadibd_options( 'radio_icon' );
									$is_icon_image = preg_match( '/https?:\/\/w{0,3}\.?[a-z0-9-_\.]+\.[a-z]+\/[a-z0-9-_\/]+.(jpg|png|gif)/i', $options['home_icon'] );
									
										if( $is_icon_image === 1 && $get_radio_icon == 'glyphicon' ) {
											echo '<span class="dadibd-warning">';
											echo __( 'Warning! You checked "Glyphicon" and insert a image uri. This is incorrectly and script returns empty. Please check "Icon Image" instead or insert a valid glyphicon class!', 'dadibd' );
											echo '</span>';
										} 
										elseif( $is_icon_image === 0 && $get_radio_icon == 'image' ) {
											echo '<span class="dadibd-warning">';
											echo __( 'Warning! You checked "Icon Image" and insert a glyphicon classes. This is incorrectly and script returns empty. Please check "Glyphicon" instead or insert a valid image url!', 'dadibd' );
											echo '</span>';
										}							
									?>
								</p>
							</td>				
						</tr>
					</table>
				</div>
				
				<h3 class="spoiler" id="dadibd-hideshow-3"><?php _e( 'Manage Category Options', 'dadibd' ); ?></h3>
				<div id="dadibd-hidden-3" <?php echo $display_none; ?>>
					<table class="dadibd-options" width="100%">
						<tr>
							<td>
								<p class="main-description">
									<?php _e( 'In this section you can manage terms/categories to build breadcrumb for every post type that has a hierarchical taxonomy (are excludes no-hierarchical).', 'dadibd' ); ?>
								</p>
								<?php $post_types = get_dadibd_list_post_type();
							
								foreach( $post_types as $post_type ) :
								
									// build name
									$post_type_name = ucwords( $post_type );
									
									// get list of taxonomies by post_type
									$custom_taxonomies = get_object_taxonomies( $post_type );
									
									// not display dropdown and post type if custom_taxonomies is empty
									if( empty( $custom_taxonomies ) ) continue;	?>
									
									<h4><?php echo $post_type_name; ?></h4>
									
									<p>
										<input id="<?php echo $post_type; ?>-categories" type="checkbox" name="dadibd_options[<?php echo $post_type; ?>_categories]" value="1" <?php checked( $options[$post_type . '_categories'], 1 ); ?> />
										<label for="<?php echo $post_type; ?>-categories"><?php _e( 'Do you want terms/categories in breadcrumb?', 'dadibd' ); ?></label><br />
										
										<label for="dadibd-<?php echo $post_type; ?>"><?php printf( __( 'Select type term/category for "%s" to display in your breadcrumb.', 'dadibd' ), $post_type_name ); ?></label><br />
										<select id="dadibd-<?php echo $post_type; ?>" name="dadibd_options[<?php echo $post_type; ?>_get_taxonomies]">
										
										<?php foreach( $custom_taxonomies as $tax ) :
											
											// Excludes all not hierarchical taxonomies
											if( is_taxonomy_hierarchical( $tax ) == true ) {
											
												$selected = $options[$post_type . '_get_taxonomies'] == $tax ? 'selected' : ''; ?>
												<option value="<?php echo $tax; ?>" <?php echo $selected; ?>><?php echo $tax; ?></option>
												
											<?php }
											
										endforeach; ?>
										
										</select><br />
										
										<input id="<?php echo $post_type; ?>-no-default-category" type="checkbox" name="dadibd_options[<?php echo $post_type; ?>_no_default_category]" value="1" <?php checked( $options[$post_type . '_no_default_category'], 1 ); ?> />
										<label for="<?php echo $post_type; ?>-no-default-category"><?php _e( 'Check if you don\'t want "Default Term/Category" if is unset term/category in your breadcrumb.', 'dadibd' ); ?></label><br />
										
										<input id="<?php echo $post_type; ?>-no-parent-category" type="checkbox" name="dadibd_options[<?php echo $post_type; ?>_no_parent_category]" value="1" <?php checked( $options[$post_type . '_no_parent_category'], 1 ); ?> />
										<label for="<?php echo $post_type; ?>-no-parent-category"><?php _e( 'Check if you don\'t want "Parent Term/Category" in your breadcrumb.', 'dadibd' ); ?></label>
									</p><?php
								
								endforeach; ?>
								<p>
									<label for="dadibd-post-types-exclude">
										<?php _e( 'Hidden post types to manage in this section. Insert name of post type. If need be, use vertical line "|" to separate each one.', 'dadibd' ); ?>
									</label><br />
									<input type="text" id="dadibd-post-types-exclude" name="dadibd_options[post_types_exclude]" value="<?php echo sanitize_text_field( $options['post_types_exclude'] ); ?>" />
									<span class="small"><?php _e( '(*)Example: "post|page|attachment". In any case will be excluded all posts type that haven\'t a hierarchical taxonomy.', 'dadibd' ); ?></span>
								</p>
							</td>
						</tr>
					</table>
				</div>
				
				<h3 class="spoiler" id="dadibd-hideshow-4"><?php _e( 'Manage Date Options', 'dadibd' ); ?></h3>
				<div id="dadibd-hidden-4" <?php echo $display_none; ?>>
					<table class="dadibd-options" width="100%">
						<tr>
							<td>
								<p class="main-description">
									<?php _e( 'In this section you can define the date to display into breadcrumb.', 'dadibd' ); ?>
								</p>
								<p>
									<span class="label"><?php _e( 'Check post type where display date in breadcrumb (has been excluded posts type without taxonomies).', 'dadibd' ); ?></span><br />
									<?php $post_types = get_dadibd_list_post_type();
									foreach( $post_types as $post_type ) : 
									
										// get list of taxonomies by post_type
										$custom_taxonomies = get_object_taxonomies( $post_type );
										
										// not display dropdown and post type if custom_taxonomies is empty
										if( empty( $custom_taxonomies ) ) continue; ?>
										
										
											<input type="checkbox" id="<?php echo $post_type; ?>-dadibd-display-date" name="dadibd_options[<?php echo $post_type; ?>_display_date]" value="1" <?php checked( $options[$post_type . '_display_date'], 1 ); ?>>
											<label for="<?php echo $post_type; ?>-dadibd-display-date"><?php echo ucwords( $post_type ); ?></label>&nbsp;&nbsp;&nbsp;

										
									<?php endforeach; ?>
								</p>
								<p>
									<label for="dadibd-format-date">
										<?php printf( __( 'Set format date. Allowed formats. Day: %s. Month: %s. Year: %s. Allowed separators: %s and space.', 'dadibd' ), '<code>j d</code>', '<code>F M m n</code>', '<code>Y y</code>', '<code>- _ / \ |</code>' ); ?>
									</label><br />
									<?php $date = filter_dadibd_date( $options['format_date'] ); ?>
									<input type="text" class="mini" id="dadibd-format-date" name="dadibd_options[format_date]" value="<?php echo $date != '' ? sanitize_text_field( $date ) : 'Y/m/d'; ?>" />
								</p>
								<p>
									<span class="small">(*)<?php printf( __( 'In this case, the breadcrumb could be: %s or %s.', 'dadibd' ), '<code>home >> Y/m/d >> cat >> the_title_post</code>', '<code>home >> cat >> Y/m/d >> the_title_post</code>' ); ?></span>
								</p>
								<p>
									<span class="label"><?php _e( 'Define type link for date*.', 'dadibd' ); ?></span><br />
									
									<?php foreach( $date_elements as $index => $value ) :
										
										$checked = $options['date_element'] == $value['value'] ? 'checked' : '';
										
										echo '<input type="radio" id="date-element-' . $value['value'] . '" name="dadibd_options[date_element]" value="' . $value['value'] . '" ' . $checked . '>'; 
										echo '<label for="date-element-' . $value['value'] . '"> ' . __('Link to: ', 'dadibd' ) . '"' . $value['label'] . '"' . '</label>&nbsp;&nbsp;&nbsp;';
										
									endforeach; ?>
										
									<?php echo get_dadibd_message_date_errors( $date, $options['date_element'] ); ?>
									
									<ul class="legend">
										<li><?php printf( __('If you check "Year", link will be: %s.', 'dadibd' ), '<code>http://www.yoursite.com/date/year/</code>' ); ?></li>
										<li><?php printf( __('If you check "Month", link will be: %s.', 'dadibd' ), '<code>http://www.yoursite.com/date/year/month/</code>' ); ?></li>
										<li><?php printf( __('If you check "Day", link will be: %s.', 'dadibd' ), '<code>http://www.yoursite.com/date/year/month/day/</code>' ); ?></li>
									</ul>					
								</p>
								<p>
									<label for="dadibd-nolink-date">
										<?php _e( 'Check it if else you don\'t want displaying the date as link.', 'dadibd' ); ?>
									</label><br />
									<input type="checkbox" id="dadibd-nolink-date" name="dadibd_options[nolink_date]" value="1" <?php checked( $options['nolink_date'], 1 ); ?>>
								</p>
								<p>
									<input type="radio" id="dadibd-position-date-1" name="dadibd_options[position_date]" value="0" <?php checked( $options['position_date'], 0 ); ?>>
									<label for="dadibd-position-date-1">
										<?php _e( 'Display date BEFORE the term/category if exists or is displayed.', 'dadibd' ); ?>
									</label><br />
									<input type="radio" id="dadibd-position-date-2" name="dadibd_options[position_date]" value="1" <?php checked( $options['position_date'], 1 ); ?>>
									<label for="dadibd-position-date-2">
										<?php _e( 'Display date AFTER the term/category if exists or is displayed.', 'dadibd' ); ?>
									</label>
								</p>
							</td>				
						</tr>
					</table>
				</div>
				
				<h3 class="spoiler" id="dadibd-hideshow-5"><?php _e( 'Manage other options', 'dadibd' ); ?></h3>
				<div id="dadibd-hidden-5" <?php echo $display_none; ?>>
					<table class="dadibd-options" width="100%">
						<tr>
							<td>
								<p class="main-description">
									<?php _e( 'In this section you can manage various options for breadcrumb.', 'dadibd' ); ?>
								</p>
								<p>
									<label for="dadibd-custom-post-type-name-link">
										<?php _e( 'Check if you want in breadcrumb that custom post type name as a link*.', 'dadibd' ); ?>
									</label><br />
									<input type="checkbox" id="dadibd-custom-post-type-name-link" name="dadibd_options[custom_post_type_name_link]" value="1" <?php checked( $options['custom_post_type_name_link'], 1 ); ?>>
									<span class="small"><?php _e( '(*)Note. Custom post type name will be shown as link if archives for the specific custom post type are enabled. Else name will be shown without link!', 'dadibd' ); ?></span>
								</p>
							</td>				
						</tr>
						<tr>
							<td>
								<p>
									<label for="dadibd-virtual-dir"><?php _e( 'Create a virtual directory in the post breadcrumb*. Allowed chars: letters, numbers, space, underscore, minus, apostrophe and ampersand.', 'dadibd' ); ?></label><br />
									<input type="text" id="dadibd-virtual-dir" name="dadibd_options[virtual_dir]" value="<?php echo $options['virtual_dir'] != '' ? sanitize_text_field( filter_dadibd_virtual_dir( $options['virtual_dir'] ) ) : ''; ?>" /><br />						
									<span class="small"><?php printf( __( '(*)Breadcrumb could be: %s. Leave blank if you don\'t want any virtual dir before the title post. ', 'dadibd' ), '<code>home >> cat >> Y/m/d >> virtual dir >> the_title_post</code>' ); ?></span>
								</p>
							</td>
						</tr>
						<tr>
							<td>
								<p>
									<label for="dadibd-cut-this-title"><?php _e( 'Set global max number of words for title post. After this number, the title post will be cutted. Set 0 to display entire title*.', 'dadibd' ); ?></label><br />
									<input type="number" id="dadibd-cut-this-title" name="dadibd_options[cut_this_title]" value="<?php echo $options['cut_this_title'] > 0 ? intval( $options['cut_this_title'] ) : 0; ?>" />
									<span class="small"><?php _e( '(*)Note. This option will be overwrite by custom title in Dadi Breadcrumb metabox.', 'dadibd' ); ?></span>
								</p>
							</td>				
						</tr>		
						<tr>
							<td>
								<p>
									<label for="dadibd-custom-sep"><?php _e( 'Select custom separator for breadcrumb. Default: "&raquo;".', 'dadibd' ); ?></label><br />
									<select id="dadibd-custom-sep" name="dadibd_options[custom_sep]" style="width:80px;">
									<?php 
										foreach( $separators as $key => $value ) :
										
										$selected = $options['custom_sep'] == $key ? 'selected' : '';
										echo '<option value="' . $key . '" ' . $selected . '>' . $value . '</option>';
										
									endforeach; ?>
									</select>
								</p>
							</td>
						</tr>
						<tr>
							<td>
								<p class="label">
									<?php _e( 'Set type of name author for breadcrumb in author page:', 'dadibd' ); ?>
								</p>
								
								<?php
								
								foreach( $author_type_names as $index => $value ) : 
									
									$checked = $options['author_name'] == $value['value'] ? 'checked' : '';
									$input = '<input type="radio" id="dadibd-' . str_replace( '_', '-', $value['value'] ) . '" name="dadibd_options[author_name]" value="' . esc_attr( $value['value'] ) . '" ' . $checked . ' />';
									$label = '<label for="dadibd-' . str_replace( '_', '-', $value['value'] ) . '">' . $value['label'] . '</label><br />';
									echo $input . $label;
									
								endforeach; ?>
							</td>
						</tr>
						<tr>
							<td>
								<p class="label">
									<?php _e( 'Dadi Breadcrumb provides for Twenty-x themes (from Eleven to Sixteen) a specific style for each one. You don\'t need to create your own style for this themes. Otherwhise see below!', 'dadibd' ); ?>
								</p>
								<p>
									<label for="dadibd-disable-css">
										<?php _e( 'If you want change default style or your theme isn\'t a Twenty-x theme, please check the box below to disable dadibd.css*.', 'dadibd' ); ?>
									</label><br />
									<input type="checkbox" id="dadibd-disable-css" name="dadibd_options[disable_css]" value="1" <?php checked( $options['disable_css'], 1 ); ?>>
								</p>
								<p>
									<?php $theme_class = 'dadibd-' . preg_replace( "/\s+/i", "-", strtolower( wp_get_theme() ) ); ?>
									<span class="small">(*)<?php _e( 'Note. You must create your own style in the stylesheet theme. Target class for your theme is: ', 'dadibd' ); echo '<code>' . esc_html( $theme_class ) . '</code>'; ?>.</span>
								</p>
							</td>				
						</tr>
					</table>
				</div>
				
				<table class="dadibd-options submit" width="100%">
				<tr>
					<td>
						<input type="submit" class="button-primary" value="<?php _e('Save Options', 'dadibd' ); ?>" />
					</td>
				</tr>
				</table>
			</form>
			<form method="post">
				<p class="submit">
					<input class="button" name="reset" type="submit" value="<?php _e( 'Reset all Settings', 'dadibd' ); ?>" />
					<input type="hidden" name="action" value="reset" />
				</p>
			</form>
			
			<div class="credits-plugin"><?php printf( __( 'Dadi Breadcrumb is created and developed by Davide Mura (c) 2016, GNU General License. Go to %splugin official page%s, or to %sWordpress Repository Plugin%s. Vers. 1.0.', 'dadibd' ), '<a href="http://www.iljester.it/dadi-breadcrumb/">', '</a>', '<a href="http://worpress.org/dadi-breadcrumb/">', '</a>' ); ?></div>
	</div>
	
	<?php if( !get_dadibd_options( 'all_visible' ) ) : ?>
	<script type="text/javascript">
		jQuery(function() {			
			  var spoiler = [1, 2, 3, 4, 5, 6];
			  jQuery.each(spoiler, function(i, v) {
				   jQuery( '#dadibd-hideshow-' + i ).addClass('plus');
					jQuery('#dadibd-hideshow-' + i).on( 'click', function() {
						jQuery( '#dadibd-hidden-' + i ).slideToggle( "slow" );
						jQuery( '#dadibd-hideshow-' + i ).toggleClass( "minus plus" );
					});
			  });
		});
	</script>
	<?php endif; ?>
	
<?php }


/*
 * Validation data setting
 *  
 * This is a callback function for dadibd_register_options_group() that validates data setting from the form
 * 
 * @param: $input
 * @return: mixed values (bool|string|int)
 * 
 * @package Dadi Breadcrumb
 * @since Since Release 1.0
 * @version 1.0 2016/05/19
 */
function dadibd_validate_input( $input ) {
	
	global $default, $jquery_positions, $separators;
	
	// get some predefinited arrays
	$inputs_array 		= get_dadibd_global_array_inputs();
	
	// rebuild radio_icons array to get value
	$radio_icons 		= $inputs_array['radio_icons'];
	$new_radio_icons = array( 
	
		$radio_icons['ri_none']['value'],
		$radio_icons['ri_image']['value'],
		$radio_icons['ri_glyphicon']['value']
		
	);
	
	// rebuild date_elements array to get value
	$date_elements		= $inputs_array['date_elements'];
	$new_date_elements = array(
	
		$date_elements['de_year']['value'],
		$date_elements['de_month']['value'],
		$date_elements['de_day']['value']
	
	);
	
	// rebuild radio_icons array to get value
	$author_type_names	= $inputs_array['author_type_names'];
	$new_author_type_names = array(
	
		$author_type_names['atn_full']['value'],
		$author_type_names['atn_nick']['value']
	
	);
	
	// x_get_taxonomies, x_categories, x_no_default_category, x_no_parent_category ( where x is a post_type in the loop )
	$post_types = get_dadibd_list_post_type();
	
	if( is_array( $post_types ) ) {
		
		foreach( $post_types as $post_type ) {
			
			// we get taxonomies array
			$custom_taxonomies = get_object_taxonomies( $post_type );
		
			foreach( $custom_taxonomies as $tax ) {
				
				if( is_taxonomy_hierarchical( $tax ) == true ) {
			
					// post_type selected
					if ( ! isset( $input[$post_type . '_get_taxonomies'] ) )
						$input[$input[$post_type . '_taxonomies']] = null;
					$input[$post_type . '_get_taxonomies'] 	= wp_filter_nohtml_kses( $input[$post_type . '_get_taxonomies'] );
					
					// no_parent_category_display
					if ( ! isset( $input[$post_type . '_categories'] ) ) $input[$post_type . '_categories'] = null;
					$input[$post_type . '_categories'] = ( $input[$post_type . '_categories'] == 1 ? true : false );
					
					// no_default_category
					if ( ! isset( $input[$post_type . '_no_default_category'] ) ) $input[$post_type . '_no_default_category'] = null;
					$input[$post_type . '_no_default_category'] = ( $input[$post_type . '_no_default_category'] == 1 ? true : false );
					
					// no_categories
					if ( ! isset( $input[$post_type . '_no_parent_category'] ) ) $input[$post_type . '_no_parent_category'] = null;
					$input[$post_type . '_no_parent_category'] = ( $input[$post_type . '_no_parent_category'] == 1 ? true : false );
				
				}
				
			}
			
			// display_date
			if ( ! isset( $input[$post_type . '_display_date'] ) ) $input[$post_type . '_display_date'] = null;
			$input[$post_type . '_display_date'] = ( $input[$post_type . '_display_date'] == 1 ? true : false );
		
		}
	
	} else {
		
		$post_types = array();
		
	}
	
	// all_visible
	if ( ! isset( $input['all_visible'] ) ) $input['all_visible'] = null;
	$input['all_visible'] = ( $input['all_visible'] == 1 ? true : false );
	
	// position_date
	if ( ! isset( $input['position_date'] ) ) $input['position_date'] = null;
	$input['position_date'] = ( $input['position_date'] == 0 ? 0 : 1 );
	
	// nolink_date
	if ( ! isset( $input['nolink_date'] ) ) $input['nolink_date'] = null;
	$input['nolink_date'] = ( $input['nolink_date'] == 1 ? true : false );
	
	// custom_post_type_name_link
	if ( ! isset( $input['custom_post_type_name_link'] ) ) $input['custom_post_type_name_link'] = null;
	$input['custom_post_type_name_link'] = ( $input['custom_post_type_name_link'] == 1 ? true : false );
	
	// disable_css
	if ( ! isset( $input['disable_css'] ) ) $input['disable_css'] = null;
	$input['disable_css'] = ( $input['disable_css'] == 1 ? true : false );
	
	// auto_append_breadcrumb
	if ( ! isset( $input['auto_append_breadcrumb'] ) )
		$input['auto_append_breadcrumb'] = 0;
	$input['auto_append_breadcrumb'] 	= intval( $input['auto_append_breadcrumb'] );
	
	// jquery_positions
	if ( ! isset( $input['type_of_position'] ) )
		$input['type_of_position'] = null;
	if ( ! in_array( $input['type_of_position'], $jquery_positions ) )
		$input['type_of_position'] = null;
	$input['type_of_position'] 	= wp_filter_nohtml_kses( $input['type_of_position'] );
	
	// date_element
	if ( ! isset( $input['date_element'] ) )
		$input['date_element'] = null;
	if ( ! in_array( $input['date_element'], $new_date_elements ) )
		$input['date_element'] = null;
	$input['date_element'] 	= wp_filter_nohtml_kses( $input['date_element'] );
		
	// radio_icons
	if ( ! isset( $input['radio_icon'] ) )
		$input['radio_icon'] = null;
	if ( ! in_array( $input['radio_icon'], $new_radio_icons ) )
		$input['radio_icon'] = null;
	$input['radio_icon'] = wp_filter_nohtml_kses( $input['radio_icon'] );
		
	// author_type_names
	if ( ! isset( $input['author_name'] ) )
		$input['author_name'] = null;
	if ( ! in_array( $input['author_name'], $new_author_type_names ) )
		$input['author_name'] = null;
	$input['author_name'] 				= wp_filter_nohtml_kses( $input['author_name'] );
	
	// custom_sep
	if ( ! isset( $input['custom_sep'] ) )
		$input['custom_sep'] = null;
	if ( ! array_key_exists( $input['custom_sep'], $separators ) )
		$input['custom_sep'] = null;
	$input['custom_sep'] 				= intval( $input['custom_sep'] );
	
	// we removes all illegal chars
	$input['target_element_to_append']  = filter_dadibd_illegal_chars( $input['target_element_to_append'] );
	
	// target_element_to_append
	$input['target_element_to_append'] 	= wp_filter_nohtml_kses( $input['target_element_to_append'] );
	
	// post_types_exclude
	$input['post_types_exclude'] 		= wp_filter_nohtml_kses( $input['post_types_exclude'] );
	
	// we filter format date
	$input['format_date']				= filter_dadibd_date( $input['format_date'] );
	
	// format_date
	$input['format_date'] 				= wp_filter_nohtml_kses( $input['format_date'] );
	
	// we filter virtual dir
	$input['virtual_dir']				= filter_dadibd_virtual_dir( $input['virtual_dir'] );
	
	// virtual_dir
	$input['virtual_dir'] 				= wp_filter_nohtml_kses( $input['virtual_dir'] );
	
	// home_icon
	$input['home_icon'] 				= wp_filter_nohtml_kses( $input['home_icon'] );
	
	// cut_this_title
	$input['cut_this_title'] 			= intval( $input['cut_this_title'] );
	
	return $input;
	
}
