<?php
/*
 * dadibd-output-functions.php
 * 
 * Mixed functions to print Dadi Breadcrumb in the Wordpress template
 * 
 * @version 	1.1.1 2016/12/29
 * @package 	Dadi Breadcrumb Plugin
 * @copyright	Copyright 2016 DAVIDE MURA  (email: muradavi@gmail.com)
 * @license		GNU General Public License GPLv2
 * @since Since Release 1.0
 * 
 **********************************************************************/

 
/* 
 * This function can be used to print breadcrumb in the template
 *  
 * @param: 		none
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19 
 */
function get_dadi_breadcrumb() {
	
	global $post, $separators;	
		
	// retrieve some object from $post
	$post_id 		= $post->ID;
	$post_type 		= $post->post_type;
	$post_title 	= $post->post_title;
	$post_author	= $post->post_author;
	$post_parent_id	= $post->post_parent;
	
	// values to pass through to the __construct method		
	$args = array( 
	
		'separator'			=> (string) get_dadibd_sep( $separators ),
		'post_type_name'	=> (string) get_dadibd_post_type_name( $post_type ),
		'term_id'			=> (int)    get_dadibd_term_id( $post_id, $post_type ),
		'term_tree'			=> (string) get_dadibd_display_term_tree( $post_id, $post_type, $separators ),
		'term_name'			=> (string) get_dadibd_term_id( $post_id, $post_type ) > 0 ? get_the_category_by_ID( get_dadibd_term_id( $post_id, $post_type ) ) : '',
		'check_isset_pt'	=> (bool)	get_dadibd_options( $post_type . '_categories' ),
		'is_display_terms'	=> (bool)	is_dadibd_display_terms( $post_id, $post_type ),
		'display_terms'		=> (string) get_dadibd_display_terms( $post_id, $post_type, $separators ),
		'post_title'		=> (string) get_dadibd_post_title( $post_id, $post_title ),
		'home_icon'			=> (string) get_dadibd_create_icon(),
		'date_post'			=> (string) get_dadibd_create_date( $post_id, $post_type, $separators ),
		'theme_class'		=> (string) get_dadibd_theme_class(),
		'archive_data'		=> (string) get_dadibd_archive_data( $separators ),
		'virtual_dir'		=> (string)	get_dadibd_options( 'virtual_dir' ),
		'home_url'			=> (string) esc_url( get_home_url() ),
		'search_query'		=> (string) esc_html( get_search_query() ),
		'author_name'		=> (string) get_dadibd_type_author_name( $post_author ),
		'att_title'			=> (string) get_dadibd_attachments_attr( $post_id, $post_parent_id, $separators, false ),
		'att_parent_title'	=> (string) get_dadibd_attachments_attr( $post_id, $post_parent_id, $separators, true ), 
		'position_date'		=> (bool)	get_dadibd_options( 'position_date' ),
		'is_admin'			=> (bool)   is_admin()

	);
	
	// get custom post types
	$custom_post_types = get_post_types( array( 'public' => true, '_builtin' => false ) );
	
	// create object
	$dadibc = new DadiBd( $args );
	
	// return breadcrumb for each type of content
	if( is_singular( 'post' ) || ( is_admin() && $post_type == 'post' ) ) {
		
		$breadcrumb = $dadibc->getDadiBreadcrumb( 'post' );
		
	}
	elseif( ( is_singular( 'page' ) && !is_front_page() ) || ( is_admin() && $post_type == 'page' ) ) {
		
		$breadcrumb = $dadibc->getDadiBreadcrumb( 'page' );
		
	}
	elseif( is_singular( 'attachment' ) || ( is_admin() && $post_type == 'attachment' ) ) {
		
		$breadcrumb = $dadibc->getDadiBreadcrumb( 'attachment' );
		
	}
	elseif( is_singular( $custom_post_types ) || is_admin() ) {
		
		$breadcrumb = $dadibc->getDadiBreadcrumb( 'custom_type' );
		
	}
	elseif( is_archive() && !is_author() ) {
		
		$breadcrumb = $dadibc->getDadiBreadcrumb( 'archive' );
		
	}
	elseif( is_author() ) {
		
		$breadcrumb = $dadibc->getDadiBreadcrumb( 'author' );
		
	}
	elseif( is_search() ) {
		
		$breadcrumb = $dadibc->getDadiBreadcrumb( 'search' );
		
	}
	elseif( is_404() ) {
		
		$breadcrumb = $dadibc->getDadiBreadcrumb( '404' );
		
	}
	else {
		
		$breadcrumb = '';
		
	}
	
	return $breadcrumb;
	
}


/*
 * This function add automatically breadcrumb in the template above the loop
 * Do not print breadcrumb in 404 error page
 *  
 * @param: 		none
 * @return: 	string
 * 
 * For add_action reference (@param and @return) see: 
 * https://developer.wordpress.org/reference/functions/add_action/
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.1 2016/12/29
 */
function get_dadi_breadcrumb_above_the_loop() {

	if( !in_the_loop() ) return;
	
	if( get_dadibd_options( 'auto_append_breadcrumb' ) != 1 ) return;
	
	echo get_dadi_breadcrumb();
	
}
add_action( 'loop_start', 'get_dadi_breadcrumb_above_the_loop' );


/*
 * This function add breadcrumb in the template using jQuery with a target class or id
 *  
 * @param: 		none
 * @return: 	string
 * 
 * For add_action reference (@param and @return) see: 
 * https://developer.wordpress.org/reference/functions/add_action/
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.1 2016/12/29
 */
function get_dadi_breadcrumb_with_jquery() {
	
	if ( get_dadibd_options( 'auto_append_breadcrumb' ) != 2 ) return;
		
		$target_element = esc_attr( get_dadibd_options( 'target_element_to_append' ) );
		
		$type_of_position = get_dadibd_options( 'type_of_position' );
	
	?>
	
	<script type="text/javascript" id="dadibd-target-element">
		jQuery(function() {
			var target_class = '<?php echo $target_element; ?>';
			var breadcrumb = '<?php echo get_dadi_breadcrumb(); ?>';

			<?php if( $type_of_position == 'prepend' ) : ?>
				jQuery( target_class ).prepend( breadcrumb );
			<?php elseif( $type_of_position == 'append' ) : ?>
				jQuery( target_class ).append( breadcrumb );
			<?php elseif( $type_of_position == 'before' ) : ?>
				jQuery( target_class ).before( breadcrumb );
			<?php elseif( $type_of_position == 'after' ) : ?>
				jQuery( target_class ).after( breadcrumb );
			<?php endif; ?>
		});
	</script><?php
	
}
add_action( 'wp_head', 'get_dadi_breadcrumb_with_jquery' );


/* 
 * This function deregister dadibd.css when the box disable_css is checked
 *  
 * @param: 		none
 * @return: 	bool, void
 * 
 * For add_action reference (@param and @return) see: 
 * https://developer.wordpress.org/reference/functions/add_action/
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 */
function dadibd_deregister_stylesheet(){
	
	if( !get_dadibd_options('disable_css' ) ) return;
	wp_dequeue_style( 'dadibd-style', DADIBD_URL . 'css/dadibd.css');
	
}
add_action( 'wp_enqueue_scripts', 'dadibd_deregister_stylesheet' );


/* 
 * This function remove with jQuery second breadcrumb if exists in the template
 *
 * DEPRECATED SINCE VERSION 1.1.1. This function will be removed in the future major release
 * 
 * This is a precaution if user pastes the function in the template and he uses auto-append
 * with jQuery or The Loop
 *  
 * @param: 		none
 * @return: 	void
 * 
 * For add_action reference (@param and @return) see: 
 * https://developer.wordpress.org/reference/functions/add_action/
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19 
 */
/* function remove_second_dadi_breadcrumb() {
	
	?>
	<script type="text/javascript" id="remove-other-dadibd">
		jQuery(function() {
			jQuery('.dadibd-breadcrumb').eq(1).remove();
		});
	</script><?php	
}
add_action( 'wp_head', 'remove_second_dadi_breadcrumb' ); */


/* 
 * This function add schema.org/WebPage for microformats
 *  
 * @param: 		none
 * @return: 	void
 * 
 * For add_action reference (@param and @return) see: 
 * https://developer.wordpress.org/reference/functions/add_action/
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.1
 * @version 	1.1 2016/07/06
 */
function add_schema_org_to_body() {
	?>
	<script type="text/javascript" id="add-schema-org">
		jQuery(function() {
			jQuery('body').attr( { "itemscope" : "", "itemtype" : "http://schema.org/WebPage" } );
		});
	</script><?php	
}
add_action( 'wp_head', 'add_schema_org_to_body' );


/* 
 * This function add custom separators to menu separators in dadi breadcrumb options page
 * 
 * Usage: copy and paste this function in your functions.php, below conditional function_exists()
 * (so if you delete dadi breadcrumb your site web is safe). 
 * Then, add your custom separator (string) or array of custom separators (array()) into $custom_sep param
 * Example string: add_custom_separator_to_dadi_breadcrumb( '--' );
 * Example array: add_custom_separator_to_dadi_breadcrumb( array( '-', '/', '\' ) );
 * Type of separators? Letters, symbols, glyphicon
 *  
 * @param: 		$custom_sep
 * @return: 	array() of separators
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19 
 */
function add_custom_separator_to_dadi_breadcrumb( $custom_sep ) {
	
	global $separators;
	
	if( !is_array( $custom_sep ) ) {
		
		$separators[] = $custom_sep;
	
	} else {
		
		foreach( $custom_sep as $sep ) {
			
			$separators[] = $sep;
			
		}
		
	}
	
	return $separators;
	
}
