<?php
/*
 * dadibd-preclass-functions.php
 * 
 * Functions to pass into __construct method
 * 
 * @version 	1.1.1 2016/12/29
 * @package 	Dadi Breadcrumb Plugin
 * @copyright	Copyright 2016 DAVIDE MURA  (email: muradavi@gmail.com)
 * @license		GNU General Public License GPLv2
 * @since Since Release 1.0
 * 
 **********************************************************************/


/* 
 * Return custom separator
 *  
 * @param: 		$separators
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 */	
function get_dadibd_sep( $separators ) {
	
	if( !is_array( $separators ) ) return ' &raquo; ';
	
	$custom_sep = get_dadibd_options( 'custom_sep' );
		
	$sep = ' ' . $separators[$custom_sep] . ' ';
	
	return $sep;

}


/*
 * Return a Category ID with or not default cat id
 *  
 * @param: 		$post_id, $post_type
 * @return: 	int
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.1 2016/12/29 
 */	
function get_dadibd_term_id( $post_id, $post_type ) { 
	
	$no_cat_default = get_dadibd_options( $post_type . '_no_default_category' );
	$sel_cat_id		= get_post_meta( $post_id, '_get_custom_breadcrumb', true );
	$taxonomy 		= get_dadibd_options( $post_type . '_get_taxonomies' );
	
	if( !has_term( '', $taxonomy ) ) return;
	
	$cat_id_default = get_the_terms( $post_id, $taxonomy )[0]->term_id;
	
	$no_cat_default = $no_cat_default && $post_type == 'post' ? '' : $cat_id_default;
	$cat_id = $sel_cat_id > 0 ? $sel_cat_id : $no_cat_default;
	
	return intval( $cat_id );
	
}


/*
 * Return a Category Parent
 *  
 * @param: 		$post_id, $post_type, $sep
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.1 2016/12/29 
 */	
function get_dadibd_display_term_tree( $post_id, $post_type, $sep ) {
	
	$taxonomy = get_dadibd_options( $post_type . '_get_taxonomies' );
	
	if( !has_term( '', $taxonomy ) ) return;
	
	$is_cat_par = get_category( get_dadibd_term_id( $post_id, $post_type ) );
	if( is_object( $is_cat_par ) && $is_cat_par->category_parent > 0 ) {
		$cat_parent = get_category_parents( get_dadibd_term_id( $post_id, $post_type ), true, get_dadibd_sep( $sep ) );
	} else {
		$cat_parent = '';
	}
	return $cat_parent;
	
}


/* 
 * Return true if terms are display
 *  
 * @param: 		$post_id, $post_type
 * @return: 	bool
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 */	
function is_dadibd_display_terms( $post_id, $post_type ) {
	
	$categories = get_dadibd_options( $post_type . '_categories' );
	$taxonomy	= get_dadibd_options( $post_type . '_get_taxonomies' );		
		
	$has_term = has_term( get_dadibd_term_id( $post_id, $post_type ), $taxonomy, $post_id ) && $categories ? true : false;
	
	return $has_term;
	
}


/* 
 * Return get terms to display in breadcrumb
 *  
 * @param: 		$post_id, $post_type, $sep
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.1 2016/07/06
 */
function get_dadibd_display_terms( $post_id, $post_type, $sep ) {

	$no_par_term = get_dadibd_options( $post_type . '_no_parent_category' );
	$term_name 	 = get_dadibd_term_id( $post_id, $post_type ) == 0 ? '' : get_the_category_by_ID( get_dadibd_term_id( $post_id, $post_type ) );
	$term_link 	 = get_dadibd_term_id( $post_id, $post_type ) == 0 ? '' : '<a rel="tag" href="' . esc_url( get_category_link( get_dadibd_term_id( $post_id, $post_type ) ) ) . '" title="' . esc_attr( $term_name ) . '"><span>' . esc_html( $term_name ) . '</span></a>' . get_dadibd_sep( $sep );
	$term_tree 	 = get_dadibd_display_term_tree( $post_id, $post_type, $sep );
	
	$display_term = $term_tree != '' && !$no_par_term ? $term_tree : $term_link;
	
	return $display_term;
	
	
}


/* 
 * Return post type name for post type in breadcrumb
 *  
 * @param: 		$post_type, $link
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.1 2016/07/06
 */
function get_dadibd_post_type_name( $post_type ) {
	
	$post_type_name = ucwords( $post_type );
	$has_archive 	= get_post_type_object( $post_type )->has_archive;
	$is_link		= get_dadibd_options( 'custom_post_type_name_link' );

	if( $is_link && $has_archive ) {
		$post_type_var = '<a href="' . get_post_type_archive_link( $post_type ) . '"><span>' . $post_type_name . '</span></a>';
	} else {
		$post_type_var = $post_type_name;
	}
	
	return $post_type_var;

}

/*
 * Return a Title Post
 *  
 * @param: 		$post_id, $post_title
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 */	
function get_dadibd_post_title( $post_id, $post_title ) {
	
	$post_title_custom  = get_post_meta( $post_id, '_get_custom_posttitle', true );
	$words 				= get_dadibd_options( 'cut_this_title' );
		
		
	if( $words > 0 ) {
		
		$post_title = trim( $post_title );
		$post_title_arr = explode( " ", $post_title );
		
		// count number of values in the array
		$count_values = count( $post_title_arr );
		
		if( $words >= $count_values ) {
			
			$post_title;
			
		} else {
			
			$new_post_title_arr = array_splice( $post_title_arr, 0, $words );
			$post_title = implode( " ", $new_post_title_arr ) . '...';
			
		}
	
	} else {
		
		$post_title;
		
	}
	
	// global cut will be overwrite by specific cut in breadcrumb metabox
	$new_post_title = $post_title_custom == '' || $post_title_custom == $post_title ? $post_title : $post_title_custom;	
		
	return esc_html( $new_post_title );	
	
}


/*
 * 
 * Create an icon for home link in a breadcrumb
 *  
 * @param: 		none
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19 
 */
function get_dadibd_create_icon() {
	
	$home_icon 		= get_dadibd_options( 'home_icon' );
	$radio_choose 	= get_dadibd_options( 'radio_icon' );
	
	$is_icon_image = preg_match( '/https?:\/\/w{0,3}\.?[a-z0-9-_\.]+\.[a-z]+\/[a-z0-9-_\/]+.(jpe?g|png|gif)/i', $home_icon );
	
	$this_icon = '';
	switch( $radio_choose ) {
		
		case 'none' :
		$this_icon = '';
		break;
		case 'image' :
			if( $is_icon_image === 1 ) {
				$this_icon = '<img src="' . esc_url( $home_icon ) . '" />';
			} else {
				$this_icon = '';
			}
		break;
		case 'glyphicon' :
			if( $is_icon_image === 0 ) {
				$this_icon = '<span class="' . esc_attr( $home_icon ) . '"></span>';
			} else {
				$this_icon = '';
			}
		break;
		
	}
	return $this_icon;
	
}


/*
 * 
 * Get date to insert in the breadcrumb
 *  
 * @param: 		$post_id, $sep
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.1 2016/07/06 
 */
function get_dadibd_create_date( $post_id, $post_type, $sep ) {

	if( !get_dadibd_options( $post_type . '_display_date' ) ) return;
	
	$year 	= get_the_date( 'Y', $post_id );
	$month 	= get_the_date( 'm', $post_id );
	$day 	= get_the_date( 'd', $post_id );
	
	$no_link_date 	= get_dadibd_options( 'nolink_date' );
	$format_date 	= get_dadibd_options( 'format_date' );
	$date_element 	= get_dadibd_options( 'date_element' );
	
	if( $no_link_date == true ) {
		
		$date = get_the_date( $format_date, $post_id );

	} 
	else {
		
		if( $date_element == 'day' ) {
		
			$date = '<a class="' . $date_element . '" rel="date" href="' . esc_url( get_day_link( $year, $month, $day ) ) . '"><span>' . get_the_date( $format_date, $post_id ) . '</span></a>';
		
		}
		elseif( $date_element == 'month' ) {
			
			$date = '<a class="' . $date_element . '" rel="date" href="' . esc_url( get_month_link( $year, $month ) ) . '"><span>' . get_the_date( $format_date, $post_id ) . '</span></a>';
		
		}
		elseif( $date_element == 'year' ) {
			
			$date = '<a class="' . $date_element . '" rel="date" href="' . esc_url( get_year_link( $year ) ) . '"><span>' . get_the_date( $format_date, $post_id ) . '</span></a>';
			
		}
						
	}
	
	return $date . get_dadibd_sep( $sep );
	
}


/*
 * 
 * Get archives data for breadcrumb
 *  
 * @param: 		$sep
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.1 2016/07/06 
 */
function get_dadibd_archive_data( $sep ) {
	
	// define current tag (tag or archive) and date type
	$current_tag 	= esc_html( single_tag_title('', false) );
	$daily_date 	= esc_html( get_the_date() );
	$monthly_date 	= esc_html( get_the_date( 'F Y' ) );
	$yearly_date 	= esc_html( get_the_date( 'Y' ) );
	
	if( is_category() ) {
		$archive_type = '<span>' . __( 'Category', 'dadibd' ) . '</span>' . get_dadibd_sep( $sep ) . '<strong>' . $current_tag . '</strong>';
	}
	elseif( is_tag() ) { 
		$archive_type = '<span>' . __( 'Tag', 'dadibd' ) . '</span>' . get_dadibd_sep( $sep ) . '<strong>' . $current_tag . '</strong>';
	}
	elseif( is_day() ) {
		$archive_type = '<span>' . __( 'Daily Archive', 'dadibd' ) . '</span>' . get_dadibd_sep( $sep ) . '<strong>' . $current_tag . '</strong>';
	}
	elseif( is_month() ) {
		$archive_type = '<span>' . __( 'Monthly Archive', 'dadibd' ) . '</span>' . get_dadibd_sep( $sep ) . '<strong>' . $current_tag . '</strong>';
	}
	elseif( is_year() ) {
		$archive_type = '<span>' . __( 'Yearly Archive', 'dadibd' ) . '</span>' . get_dadibd_sep( $sep ) . '<strong>' . $current_tag . '</strong>';
	}
	else {
		$archive_type = '';
	}
	
	return $archive_type;
	
}


/*
 * 
 * Get type of author name
 *  
 * @param: 		$post_author
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19 
 */
function get_dadibd_type_author_name( $post_author ) {

	$author_full_name 	= get_the_author_meta( 'first_name', $post_author ) . ' ' . get_the_author_meta( 'last_name', $post_author );
	$author_nickname 	= get_the_author_meta( 'nickname', $post_author );

	$name = get_dadibd_options( 'author_name' ) == 'author_full_name' ? $author_full_name : $author_nickname;
	
	return $name;
		
}


/*
 * 
 * Get attachment attributes for breadcrumb
 *  
 * @param: 		$post_id, $post_parent_id, $sep, $parent_title
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19 
 */
function get_dadibd_attachments_attr( $post_id, $post_parent_id, $sep, $parent_title = false ) {
		
	$att_title			= esc_html( get_the_title( $post_id ) );
	$att_parent_id 		= $post_parent_id;
	$att_parent_title 	= $att_parent_id != null ? esc_html( get_the_title( $att_parent_id ) ) . get_dadibd_sep( $sep ) : '';
	
	if( $parent_title == true ) {
		
		$att_data = $att_parent_title;
		
	} else {
		
		$att_data = $att_title;
		
	}
	
	return $att_data;

}


/* 
 * Create and add a class for custom style based of the name theme
 *  
 * @param: 		none
 * @return: 	string
 * 
 * @package 	Dadi Breadcrumb
 * @since 		Since Release 1.0
 * @version 	1.0 2016/05/19
 */	
function get_dadibd_theme_class() {
	
	$theme_class = ' dadibd-' . preg_replace( "/\s+/i", "-", strtolower( wp_get_theme() ) );
	
	return esc_attr( $theme_class );
	
}
